==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/tr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Dosyalar indirme sınırı",
    "File link share download limit" : "Dosya bağlantısı paylaşımı indirme sınırı",
    "This app allows limiting the number of downloads for external link shares." : "Bu uygulama dış bağlantı paylaşımlarının indirme sayısının sınırlanmasını sağlar.",
    "Limit downloads" : "İndirmeleri sınırla",
    "Set download limit" : "İndirme sınırını ayarla",
    "Setting a new limit will reset the download count" : "Yeni bir sınır ayarlandığında indirme sayısı sıfırlanır",
    "The minimum limit is 1" : "En az sınır 1 olabilir",
    "Failed to set download limit" : "İndirme sınırı ayarlanamadı",
    "Failed to remove download limit" : "İndirme sınırı kaldırılamadı",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 indirme daha yapılabilir","{count} indirme daha yapılabilir"],
    "Download limit" : "İndirme sınırı",
    "Configure the default download limit for external shares." : "Dış paylaşımların varsayılan indirme sınırını yapılandırın.",
    "Set default download limit" : "Varsayılan indirme sınırını ayarla",
    "Failed to set default download limit" : "Varsayılan indirme sınırı ayarlanamadı",
    "You have reached the maximum amount of downloads allowed" : "En fazla indirme sayısı sınırına ulaştınız",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Bu paylaşımın indirme sayısı sınırlanmış. Yeni bir indirme başlatmak istediğinize emin misiniz?"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/files_downloadlimit/l10n/tr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Dosyalar indirme sınırı",
    "File link share download limit" : "Dosya bağlantısı paylaşımı indirme sınırı",
    "This app allows limiting the number of downloads for external link shares." : "Bu uygulama dış bağlantı paylaşımlarının indirme sayısının sınırlanmasını sağlar.",
    "Limit downloads" : "İndirmeleri sınırla",
    "Set download limit" : "İndirme sınırını ayarla",
    "Setting a new limit will reset the download count" : "Yeni bir sınır ayarlandığında indirme sayısı sıfırlanır",
    "The minimum limit is 1" : "En az sınır 1 olabilir",
    "Failed to set download limit" : "İndirme sınırı ayarlanamadı",
    "Failed to remove download limit" : "İndirme sınırı kaldırılamadı",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 indirme daha yapılabilir","{count} indirme daha yapılabilir"],
    "Download limit" : "İndirme sınırı",
    "Configure the default download limit for external shares." : "Dış paylaşımların varsayılan indirme sınırını yapılandırın.",
    "Set default download limit" : "Varsayılan indirme sınırını ayarla",
    "Failed to set default download limit" : "Varsayılan indirme sınırı ayarlanamadı",
    "You have reached the maximum amount of downloads allowed" : "En fazla indirme sayısı sınırına ulaştınız",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Bu paylaşımın indirme sayısı sınırlanmış. Yeni bir indirme başlatmak istediğinize emin misiniz?",
    "Allow to limit the number of downloads for link shares" : "Bağlantı paylaşımları için indirme sayısı sınırlanabilsin",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "Bu paylaşım {limit} indirme ile sınırlanmış. {countLeft} kez daha indirilebilir."
},
"nplurals=2; plural=(n > 1);");
